Skip to contents

Assigns seasons such that the last deploymentEnd within any season strictly precedes the first deploymentStart of the next.

Usage

find_seasons(
  deployments,
  locationID = locationID,
  deploymentStart = deploymentStart,
  deploymentEnd = deploymentEnd
)

Arguments

deployments

A dataframe of deployment information. Must contain columns locationID, deploymentStart, and deploymentEnd (or equivalents specified via the corresponding arguments).

locationID

<data-masking> Column name for site identifiers. Default: locationID.

deploymentStart

<data-masking> Date. Column name for deployment start dates. Default: deploymentStart.

deploymentEnd

<data-masking> Date. Column name for deployment end dates. Default: deploymentEnd.

Value

The deployments dataframe with additional factor column season, labeled with year_quarter of the midpoint of each season, arranged by deploymentStart.