Find potential ARU failure periods
find_failures.RdIdentifies potential failure periods by searching for unusually long gaps between consecutive detections at each site. Best used on a dataframe of all records including null records, as a suitable gap threshold requires knowledge of expected detection rates.
Arguments
- df
A dataframe of records. Must contain columns
deploymentIDandeventStart(or equivalents).- deploymentID
<
data-masking> Column name for site identifiers. Default:deploymentID.- eventStart
<
data-masking>POSIXt. Observation timestamps. Default:eventStart.- buffer_days
Positive integer. Number of days after the last detection and before the next detection to exclude from the inferred failure period. For example,
buffer_days = 2means the failure period starts 2 days after the last detection and ends 2 days before the next detection.