Plot interspecific correlations
plot_correlations.RdPlot pairwise species correlations for different model components.For occupancy, interspecific correlations are only estimated for responses to site-level predictors. For detection, interspecific correlations are potentially estimated for responses to site-level predictors, survey-level predictors, random site effects, random survey effects, and potentially Poisson OLREs.
Usage
plot_correlations(
fit,
submodel = c("detection", "occupancy"),
species = NULL,
...
)Arguments
- fit
A fitted model object from
fit_model().- submodel
character. Correlations of submodel to plot. One of"detection"(default) or"occupancy".- species
character. Vector of species to plot. IfNULL(default), all species are plotted. Must be one ofattr(occARU_data, "species").- ...
Additional arguments passed to
ggdist::stat_pointinterval().