Plot intercepts
plot_intercepts.RdPlot species-specific intercepts for occupancy and detection, by default back-transformed to the original scale.
Usage
plot_intercepts(
fit,
back_transform = TRUE,
by_region = FALSE,
species = NULL,
regions = NULL,
...
)Arguments
- fit
A fitted model object from
occARU().- back_transform
logical. IfTRUE(default), intercepts are back-transformed to the natural scale viainv_logit()for occupancy andexp()for detection rates. IfFALSE, values are left on the scale of the link functions (logit for occupancy and log for detection).- by_region
logical. Whether to plot intercepts by region, if multiple regions were included.- species
character. Vector of species to plot. IfNULL(default), all species are plotted. Must be one ofattr(occARU_data, "species").- regions
character. Vector of regions to plot. IfNULL(default), all regions are plotted. Must be one ofattr(occARU_data, "regions").- ...
Additional arguments passed to
ggdist::stat_pointinterval().