Plot intercepts
plot_intercepts.RdPlot species-specific intercepts for occupancy and detection, by default back-transformed to the orginal scale.
Arguments
- fit
A fitted model object from
fit_model().- species
character. Vector of species to plot. IfNULL(default), all species are plotted. Must be one ofattr(occARU_data, "species").- back_transform
logical. IfTRUE(default), intercepts are back-transformed to the natural scale viainv_logit()for occupancy andexp()for detection rates. IfFALSE, values are left on the scale of the link functions (logit for occupancy and log for detection).- ...
Additional arguments passed to
ggdist::stat_pointinterval().