Plot observations
plot_observations.RdPlot observations of the data used in the occARU model, aggregated to the chosen survey length and summed across sites.
Arguments
- data
An
occARU_dataobject frommake_data().- by_region
logical.Whether to summarise observations by region, if multiple regions were included. Default:FALSE.- species
character. Vector of species to plot. IfNULL(default), all species are plotted. Must be one ofattr(occARU_data, "species").- regions
character. Vector of regions to use. IfNULL(default), all regions are used. Must be one ofattr(occARU_data, "regions").- ...
Additional arguments passed to
ggplot2::geom_point().
Value
A ggplot object with occARU-specific attributes attached:
plot_dataThe tibble used to produce the plot.