Plot temporal detection rates
plot_surveys.RdPlots species-level temporal detection rates combining survey predictors
averaged over sites (if included via make_data()) and survey random effects
(kappa).
Usage
plot_surveys(
fit,
species = NULL,
surveys = NULL,
seasons = NULL,
intercepts = TRUE,
back_transform = TRUE,
include_predictors = TRUE,
ndraws = NULL,
seed = NULL,
palette = "YlGn",
...
)Arguments
- fit
A fitted model object from
occARU().- species
character. Vector of species to plot. IfNULL(default), all species are plotted. Must be one ofattr(occARU_data, "species").- surveys
character. Vector of survey dates to plot. IfNULL(default), all surveys are plotted. Must be one ofattr(occARU_data, "surveys").- seasons
character. Vector of seasons to plot. IfNULL(default), all seasons are plotted. Must be one ofattr(occARU_data, "seasons").- intercepts
logical. IfTRUE(default), species-level baseline log detection rates are added to the survey effects. IfFALSE, only the temporal deviations are plotted on the log scale.- back_transform
logical. Only used whenintercepts = TRUE. IfTRUE(default), log detection rates are back-transformed to the natural scale viaexp(). IfFALSE, values are left on the log scale.- include_predictors
logical. IfTRUE(default), includes predictors in the survey effects, if included. IfFALSE, only plots the random effects.- ndraws
Positive integer. Number of draws to use for plotting, passed to
tidybayes::spread_rvars(). Default:NULL(uses all draws).- seed
Positive numeric. Seed to use when subsampling draws when
ndrawsis notNULL. Default: random integer.- palette
character. Colour palette to be passed toggplot2::scale_fill_brewer(). Default:"YlGn".- ...
Additional arguments passed to
ggdist::stat_lineribbon()such as.widthandpoint_interval.